<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>View</name>
    <message>
        <location filename="../View.js" line="+64"/>
        <source>View Tools</source>
        <translation>Aanzicht gereedschappen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show view tools</source>
        <translation>Aanzicht gereedschappen tonen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>View</source>
        <translation>Beeld</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;View</source>
        <translation>&amp;Aanzicht</translation>
    </message>
</context>
</TS>
